<?php
/**
 * @file
 * Main admin settings functionality.
 */

/**
 * Main settings page.
 */
function openadstream_admin_settings() {
  $form = array();
  
  // Main settings.
  $form['main_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#description' => t("These settings should be provided by 24/7 RealMedia."),
  );
  $form['main_settings']['openadstream_oas_hostname'] = array(
    '#type' => 'textfield',
    '#title' => t('Open AdStream Hostname'),
    '#default_value' => variable_get('openadstream_oas_hostname', 'oascentral.247realmedia.com'),
    '#size' => 50,
    '#maxlength' => 100,
    '#description' => 'The hostname used to request ads, will be provided by 24/7 Real Media.  Do not include the initial "http://" nor any slashes, just the bare hostname.',
    '#required' => TRUE,
  );
  $form['main_settings']['openadstream_hostname'] = array(
    '#type' => 'textfield',
    '#title' => t('Site Hostname'),
    '#default_value' => variable_get('openadstream_hostname', ''),
    '#size' => 50,
    '#maxlength' => 100,
    '#description' => 'By default, we will be using the current hostname',
  );

  // Allow the taxonomy system to be used to select paths.
  $vocabs = taxonomy_get_vocabularies();
  $active_vocabs = variable_get('openadstream_active_vocabs', array());
  $options = array();
  foreach ($vocabs as $vid => $vocab) {
    $options[$vid] = $vocab->name;
  }
  // If items were selected before, expand the fieldset.
  $form['taxonomy_paths'] = array(
    '#type' => 'fieldset',
    '#title' => t('Taxonomy-based Path Selection'),
    '#collapsible' => TRUE,
    '#collapsed' => empty($active_vocabs),
  );
  $form['taxonomy_paths']['openadstream_active_vocabs'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enabled Vocabularies'),
    '#options' => $options,
    '#default_value' => $active_vocabs,
  );

  // Disable ads for some pages.
  $form['disable'] = array(
    '#type' => 'fieldset',
    '#title' => t('Disable Pages (optional)'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['disable']['openadstream_disable_admin'] = array(
    '#type' => 'checkbox',
    '#title' => t('Disable on Admin Pages'),
    '#default_value' => variable_get('openadstream_disable_admin', TRUE),
    '#description' => t('Override other settings and just disable on all admin pages - /admin, /admin/*'),
  );
  $form['disable']['openadstream_disable_nodeedit'] = array(
    '#type' => 'checkbox',
    '#title' => t('Disable on Node Edit Pages'),
    '#default_value' => variable_get('openadstream_disable_nodeedit', TRUE),
    '#description' => t('Override other settings and just disable on all node edit pages - /node/add*, /node/*/edit'),
  );

  // Pagename customizations.
  $form['pagename_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pagename Settings (optional)'),
    '#collapsible' => TRUE,
    '#collapsed' => !(variable_get('openadstream_pagename', '') || variable_get('openadstream_add_basepath', TRUE) || variable_get('openadstream_querystring', '')),
  );
  $form['pagename_settings']['openadstream_pagename'] = array(
    '#type' => 'textfield',
    '#title' => t('Fixed Page Name'),
    '#default_value' => variable_get('openadstream_pagename', ''),
    '#size' => 50,
    '#maxlength' => 50,
    '#description' => '(optional) All page requests will load the same pagename value. Only use this for testing, will produce unwanted results in a production environment.',
  );
  $form['pagename_settings']['openadstream_add_basepath'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add Base Path'),
    '#default_value' => variable_get('openadstream_add_basepath', TRUE),
    '#description' => '(optional) By default the pagename variable will be prepended
      by the string provided by base_path().  In occasions when you are
      running the site within a subdirectory but do not want that directory
      name added, disable this setting.',
  );
  $form['pagename_settings']['openadstream_querystring'] = array(
    '#type' => 'textfield',
    '#title' => t('URL String'),
    '#default_value' => variable_get('openadstream_querystring', ''),
    '#size' => 10,
    '#maxlength' => 20,
    '#description' => '(optional) Override the configured pagename via a URL string.',
  );
  
  // Background color.
  $form['background_color'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => !variable_get('openadstream_default_bgcolor', ''),
    '#title' => t('Default Page Background Color (optional)'),
    '#description' => '',
  );
  $form['background_color']['bgcolor'] = array(
    '#type' => (module_exists('colorpicker') ? 'colorpicker_' : '') . 'textfield',
    '#title' => t('HEX Color Code'),
    '#default_value' => variable_get('openadstream_default_bgcolor', ''),
    '#required' => FALSE,
    '#maxlength' => '7',
    '#size' => '10',
    '#description' => 'The default color code for the page background.  This may be used to .  Optional.',
  );

  // Gutter ads.
  // Grab an array of all positions.
  $positions = openadstream_all_positions_names();
  // Insert an empty element at the front to make the selection optional.
  array_unshift($positions, '');
  // Some strings used later.
  $help_pos = t('Position name to use in this gutter.');
  $help_css = t('Custom CSS for ensuring the gutter ad displays correctly.  This should not be modified.  Note: do not use doublequotes in this code or it will break the output.');
  $help_pad = t('Optional padding (in pixels) to show between the gutter and the page content.');
  $form['gutter'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gutter Ads (optional)'),
    '#collapsible' => TRUE,
    '#collapsed' => !variable_get('openadstream_gutter_enabled', FALSE),
    '#description' => t("Allows you to display ads in the page gutters, one ad per side.  For flexibility, the ads are not dependent upon each other, so you can display one but not the other."),
  );
  $form['gutter']['openadstream_gutter_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Gutter Ads'),
    '#description' => t('Master switch for all gutter ads.  Disabling theis will not affect other settings.'),
    '#default_value' => variable_get('openadstream_gutter_enabled', FALSE),
  );
  $form['gutter']['openadstream_gutter_dom'] = array(
    '#type' => 'textfield',
    '#title' => t('DOM Element for Width'),
    '#description' => t('The DOM element to use to decide the page width, e.g. "#page".  This should be the outermost page element on your page, usually the first DIV inside your BODY tag.  This is identified using jQuery selection strings so you can get advanced with this, if needed.'),
    '#default_value' => variable_get('openadstream_gutter_dom', '#page'),
  );
  $form['gutter']['gutter_left'] = array(
    '#type' => 'fieldset',
    '#title' => t('Left Gutter'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['gutter']['gutter_left']['openadstream_gutter_left'] = array(
    '#type' => 'select',
    '#title' => t('Gutter Position'),
    '#description' => $help_pos,
    '#options' => $positions,
    '#required' => FALSE,
    '#default_value' => variable_get('openadstream_gutter_left', ''),
  );
  $form['gutter']['gutter_left']['openadstream_gutter_left_css'] = array(
    '#type' => 'textfield',
    '#title' => t('Positioning CSS'),
    '#description' => $help_css,
    '#default_value' => variable_get('openadstream_gutter_left_css', 'position:absolute;top:0;left:0;overflow:hidden;z-index:-1;'),
  );
  $form['gutter']['gutter_left']['openadstream_gutter_left_pad'] = array(
    '#type' => 'select',
    '#title' => t('Padding (px)'),
    '#options' => range(0, 100),
    '#description' => $help_pad,
    '#default_value' => variable_get('openadstream_gutter_left_pad', 0),
  );
  $form['gutter']['gutter_right'] = array(
    '#type' => 'fieldset',
    '#title' => t('Right Gutter'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['gutter']['gutter_right']['openadstream_gutter_right'] = array(
    '#type' => 'select',
    '#title' => t('Right Gutter Position'),
    '#description' => $help_pos,
    '#options' => $positions,
    '#required' => FALSE,
    '#default_value' => variable_get('openadstream_gutter_right', ''),
  );
  $form['gutter']['gutter_right']['openadstream_gutter_right_css'] = array(
    '#type' => 'textfield',
    '#title' => t('Positioning CSS'),
    '#description' => $help_css,
    '#default_value' => variable_get('openadstream_gutter_right_css', 'position:absolute;top:0;right:0;overflow:hidden;z-index:-1;'),
  );
  $form['gutter']['gutter_right']['openadstream_gutter_right_pad'] = array(
    '#type' => 'select',
    '#title' => t('Padding (px)'),
    '#options' => range(0, 100),
    '#description' => $help_pad,
    '#default_value' => variable_get('openadstream_gutter_right_pad', 0),
  );

  // Content types default pagename.
  $form['content_types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Content Type Default Pagenames (optional)'),
    '#description' => t('Pagenames may be assigned as a default for content types to be then overridden on a per-node basis.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $types = node_get_types();
  asort($types);
  foreach ($types as $name => $type) {
    $form['content_types']['openadstream_pagename_'. $name] = array(
      '#type' => 'textfield',
      '#title' => $type->name,
      '#size' => 30,
      '#maxlength' => 75,
      '#default_value' => variable_get('openadstream_pagename_'. $name, ''),
    );
  }
  
  // Display this as a system settings form.
  return system_settings_form($form);
}
