<?php
/**
 * @file
 * Admin functionality for controlling the Open AdStream pagenames.
 */

/**
 * Pagenames settings page.
 */
function openadstream_admin_pagenames() {
  // Add a header.
  $output = "<h2>" . t('Pagenames') . "</h2>\n";
  $output .= "<p>" . t("Override the Open AdStream pagename variable based on
    the page path. A pagename with path &lt;front&gt; will replace the pagename
    on the home page. The '*' character can be used as a wildcard. The path
    blog/* matches all pages under blog/.") . "</p>\n";
  $output .= "<p>" . t("Pagenamess are checked by weight from lowest to
    highest. The first entry that matches the current path is used.") . "</p>\n";
  $output .= "<br />\n";

  // Compile the custom pagenames.
  $pagenames = openadstream_all_pagenames_by_admin();
  $output .= "<h3>" . t('Pagenames Added by Users') . "</h3>\n";

  // If there were no positions, display a message.
  if (empty($pagenames)) {
    $output .= "<p>". t("No pagenames have been added by users.") ."</p>";
  }
  
  else {
    // The table header.
    $header = array(
      t('Pagename'), 
      t('Weight'),
      t('Path'),
      t('Operations'),
    );
  
    // Add each row.
    $rows = array();
    foreach ($pagenames as $pagename) {
      $edit_link = l('edit', 'admin/build/openadstream/pagenames-edit/'. $pagename['pagename_id']);
      $delete_link = l('delete', 'admin/build/openadstream/pagenames-delete/'. $pagename['pagename_id']);
    
      $rows[] = array(
        $pagename['pagename'],
        $pagename['weight'],
        htmlspecialchars($pagename['path']),
        $edit_link .' | '. $delete_link,
      );
    }

    // Compile a themed table.
    $output .= theme('table', $header, $rows);
  }

  // Add some separation between the two lists.
  $output .= "<br />\n";

  // Compile the default pagenames.
  $pagenames = openadstream_all_pagenames_by_hook();
  $output .= "<h3>" . t('Pagenames Added by Modules') . "</h3>\n";

  // If there were no positions, display a message.
  if (empty($pagenames)) {
    $output .= "<p>". t("No pagenames have been added by modules.") ."</p>";
  }
  
  else {
    // The table header.
    $header = array(
      t('Pagename'), 
      t('Weight'),
      t('Path'),
      t('Module'),
    );

    // Add each row.
    $rows = array();
    foreach ($pagenames as $pagename) {
      $rows[] = array(
        $pagename['pagename'],
        $pagename['weight'],
        htmlspecialchars($pagename['path']),
        $pagename['module'],
      );
    }
  
    // Compile a themed table.
    $output .= theme('table', $header, $rows);
  }

  return $output;
}

function openadstream_admin_pagenames_add() {
  $pagename = array(
    'path' => '',
    'pagename' => '',
    'weight' => 0,
    'content_type' => '',
  );
  return openadstream_admin_pagenames_form($pagename);
}

function openadstream_admin_pagenames_edit(&$form_state, $pagename_id) {
  $pagename = db_fetch_array(db_query("SELECT p.pagename_id, p.path, p.pagename, p.weight FROM {openadstream_pagenames} p WHERE p.pagename_id = %d", $pagename_id));
  return openadstream_admin_pagenames_form($pagename);
}

function openadstream_admin_pagenames_form($pagename) {
  $form = array();
  
  // If this is an edit page then save the primary key.
  if (array_key_exists('position_id', $pagename) && is_numeric($pagename['pagename_id'])) {
    $form['pagename']['pagename_id'] = array(
      '#type' => 'value',
      '#value' => $pagename['pagename_id'],
    );
  }

  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pagename Settings'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  
  $form['settings']['pagename'] = array(
    '#type' => 'textfield',
    '#title' => t('Pagename'),
    '#description' => t('The default pagename will be overridden with this value when the selection method matches.'),
    '#size' => 30,
    '#maxlength' => 75,
    '#required' => TRUE,
    '#default_value' => $pagename['pagename'],
  );
  
  $form['settings']['path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path'),
    '#description' => t("Enter a drupal path. The '*' character may be used as a wildcard. Example paths are 'blog' for the blog page and 'blog/*' for every personal blog. &lt;front&gt; is the front page."),
    '#size' => 30,
    '#maxlength' => 255,
    '#default_value' => $pagename['path'],
  );
  
  $form['settings']['weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight'),
    '#description' => t('Pagenames are applied by order of weight. If a path matches multiple pagename entries then the entry with the highest weight wins.'),
    '#default_value' => $pagename['weight'],
    '#size' => 5,
    '#maxlength' => 5,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );

  return $form;
}

function openadstream_admin_pagenames_edit_submit($form, &$form_state) {
  $values = $form_state['values'];
  $sql = "UPDATE {openadstream_pagenames} SET pagename = '%s', weight = %d, path = '%s' WHERE pagename_id = %d";
  db_query($sql, $values['pagename'], $values['weight'], $values['path'], $values['pagename_id']);
  openadstream_clear_pagenames_cache();
  drupal_set_message('Pagename pagename has been updated');
  drupal_goto('admin/build/openadstream/pagenames');
}

function openadstream_admin_pagenames_add_submit($form, &$form_state) {
  $values = $form_state['values'];
  $sql = "INSERT INTO {openadstream_pagenames} (pagename, weight, path) VALUES ('%s', %d, '%s')";
  db_query($sql, $values['pagename'], $values['weight'], $values['path']);
  openadstream_clear_pagenames_cache();
  drupal_set_message(t('The pagename pagename %name has been created', array('%name' => $values['pagename'])));
  drupal_goto('admin/build/openadstream/pagenames');
}

/**
 * Verify a pagename is to be deleted.
 */
function openadstream_admin_pagenames_delete(&$form_state, $pagename_id) {
  $pagename = db_fetch_array(db_query("SELECT * FROM {openadstream_pagenames} WHERE pagename_id = %d", $pagename_id));
  
  drupal_set_title(t("Pagename '@name'", array('@name' => $pagename['pagename'])));
  
  $form = array(
    'pagename_id' => array(
      '#type' => 'value',
      '#value' => $pagename_id,
    ),
  );
  
  return confirm_form($form,
    t("Are you sure you want to delete pagename '%name'?", array('%name' => $pagename['pagename'])),
    'admin/build/openadstream/pagenames',
    t('This action cannot be undone'),
    t('Delete'), t('Cancel')
  );
}

/**
 * Delete a pagename.
 */
function openadstream_admin_pagenames_delete_submit($formid, &$form_state) {
  if ($form_state['values']['confirm']) {
    db_query("DELETE FROM {openadstream_pagenames} WHERE pagename_id = %d", $form_state['values']['pagename_id']);
    openadstream_clear_pagenames_cache();
    drupal_set_message(t('The pagename has been deleted'));
  }
  $form_state['redirect'] = 'admin/build/openadstream/pagenames';
}

//TODO: List functions that have the different hooks enabled to help identify where they're coming from.
