<?php
/**
 * @file
 * Admin functionality for controlling the Open AdStream positions.
 */

/**
 * Positions setting page.
 */
function openadstream_admin_positions() {
  $output = '';
  
  // Custom positions.
  $positions = openadstream_all_positions_by_admin();
  $output .= "<h3>" . t('Positions Added by Users') . "</h3>\n";
  
  // If there were no positions, display a message.
  if (empty($positions)) {
    $output .= "<p>". t("No positions have been added by users.") ."</p>";
  }
  
  else {
    // The table header.
    $header = array(
      t('Position Name'),
      t('Advanced? (count)'),
      t('Description'),
      t('Operations'),
    );
  
    // Add each row.
    $rows = array();
    foreach ($positions as $position) {
      if ($position['advanced'] === FALSE) {
        $advanced = t('No');
      }
      else {
        $advanced = t('Yes') .' ('. count($position['advanced']) .')';
      }
      $rows[] = array(
        $position['name'],
        $advanced,
        $position['description'],
        l('delete', 'admin/build/openadstream/positions-delete/'. $position['position_id']),
      );
    }

    // Compile a themed table.
    $output .= theme('table', $header, $rows);
  }

  // Add some separation between the two lists.
  $output .= "<br />\n";

  // Default positions.
  $positions = openadstream_all_positions_by_hook();
  $output .= "<h3>" .  t('Positions Added by Modules') . "</h3>\n";

  // If there were no positions, display a message.
  if (empty($positions)) {
    $output .= "<p>". t("No positions have been added by modules.") ."</p>";
  }

  else {
    // The table header.
    $header = array(
      t('Position Name'),
      t('Advanced? (count)'),
      t('Description'),
      t('Module'),
    );
  
    // Add each row.
    $rows = array();
    foreach ($positions as $position) {
      if ($position['advanced'] === FALSE) {
        $advanced = t('No');
      }
      else {
        $advanced = t('Yes') .' ('. count($position['advanced']) .')';
      }
      $rows[] = array(
        $position['name'],
        $advanced,
        $position['description'],
        $position['module'],
      );
    }
  
    // Compile a themed table.
    $output .= theme('table', $header, $rows);
  }

  return $output;
}

function openadstream_admin_positions_add() {
  $form = array();
  
  $form['position'] = array(
    '#type' => 'fieldset',
    '#title' => t('Position Settings'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  
  $form['position']['position_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Position Name'),
    '#description' => t('The position name is set in the OAS management interface.  24/7 RealMedia will provide this value.'),
    '#size' => 30,
    '#maxlength' => 75,
    '#required' => TRUE,
  );

  $form['position']['position_description'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#description' => t('An optional description to help remember the details of the advertisement position.'),
    '#size' => 30,
    '#maxlength' => 100,
    '#required' => FALSE,
  );

  $form['position']['position_advanced'] = array(
    '#type' => 'checkbox',
    '#title' => t('Advanced settings allowed?'),
    '#description' => t('Ads that have this enabled will not be displayed unless an Advanced Setting does so.  Along with enabling the ads by path they may also be limited to a specific date range.'),
  );
    
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );
  
  return $form;
}

function openadstream_admin_positions_add_validate($form, &$form_state) {
  $values = $form_state['values'];
  
  if (db_result(db_query("SELECT COUNT(*) FROM {openadstream_positions} WHERE name = '%s'", $values['position_name']))) {
    form_set_error('info', t('The position name %name is already in use', array('%name' => $values['position_name'])));
  }
}

function openadstream_admin_positions_add_submit($form, &$form_state) {
  $values = $form_state['values'];
  db_query("INSERT INTO {openadstream_positions} (name, advanced, description) VALUES ('%s', '%s')", $values['position_name'], $values['position_advanced'], $values['position_description']);
  openadstream_clear_positions_cache();
  drupal_set_message(t('The position %name has been created', array('%name' => $values['position_name'])));
  drupal_goto('admin/build/openadstream/positions');
}

function openadstream_admin_positions_delete(&$form_state, $position_id) {
  $position = db_fetch_array(db_query("SELECT * FROM {openadstream_positions} WHERE position_id = %d", $position_id));
  
  drupal_set_title(t("Position '@name'", array('@name' => $position['name'])));
  
  $form = array(
    'position_id' => array(
      '#type' => 'value',
      '#value' => $position_id,
    ),
  );
  
  return confirm_form($form,
    t("Are you sure you want to delete position '%name'?", array('%name' => $position['name'])),
    'admin/build/openadstream/positions',
    t('This action cannot be undone'),
    t('Delete'), t('Cancel')
  );
}

function openadstream_admin_positions_delete_submit($formid, &$form_state) {
  if ($form_state['values']['confirm']) {
    db_query("DELETE FROM {openadstream_positions} WHERE position_id = %d", $form_state['values']['position_id']);
    openadstream_clear_positions_cache();
    drupal_set_message(t('The position has been deleted'));
  }
  $form_state['redirect'] = 'admin/build/openadstream/positions';
  _block_rehash();
}

//TODO: 'edit' action
//TODO: Function to clear cache
