<?php
/**
 * @file
 * Admin functionality for controlling the Open AdStream advanced pagename
 * settings.
 */

/**
 * Advanced settings page.
 */
function openadstream_admin_advanced() {
  $output = '';
  
  // Intro message
  $output .= "<h2>" . t("Advanced Position Settings") . "</h2>\n";
  $output .= "<p>" . t("By using advanced settings you can set the page background, custom paths and set date/time restrictions on when specific advertisements should be displayed, overriding the normal block visibility rules or panel pane configuration.") . "</p>\n";
  
  // See if any ad positions have the advanced options enabled.
  $positions = openadstream_all_positions_advanced(TRUE);

  // No positions found.
  if (empty($positions)) {
    $output .= "<p>". t('No ad positions have been set to allow advanced settings.') ."</p>\n";
  }
  else {
  
    // Show the positions that are enabled for advanced settings.
    $output .= "<p>" . t('The following positions can have advanced settings added:') . "</p>\n";
    $output .= "<ul><li>" . implode('</li><li>', $positions) . "</li></ul>\n";

    // Custom positions.
    $positions = openadstream_list_advanced_all();
    $output .= "<h3>" . t('Advanced Position Settings Added by Users') . "</h3>\n";

    // If there were no positions, display a message.
    if (empty($positions)) {
      $output .= "<p>". t("No advanced settings have been added by users.") ."</p>";
    }
  
    else {
      // The table header.
      $header = array(
        t('Position'),
        t('Path(s)'),
        t('Terms(s)'),
        t('Date From'),
        t('Date To'),
        t('BG Color'),
        t('Operations'),
      );
  
      // Add each row.
      $rows = array();
      $last_position = '';
      foreach ($positions as $position => $records) {
        foreach ($records as $x => $record) {
          // Format the From Date field.
          if (empty($gutter['date_from'])) {
            $date_from = "<em>" . t('immediately') . "</em>";
          }
          else {
            $date_from = format_date($gutter['date_from'], 'short');
            if ($gutter['date_from'] > $now) {
              $classes[] = 'inactive';
              $date_from .= ' - <em>' . t('inactive') . '</em>';
            }
          }
          // Format the To Date field.
          if (empty($gutter['date_to'])) {
            $date_to = '<em>' . t('no expiration') . '</em>';
          }
          else {
            $date_to = format_date($gutter['date_to'], 'short');
            if ($gutter['date_to'] < $now) {
              $classes[] = 'expired';
              $date_to .= ' - <em>' . t('expired!') . '</em>';
            }
          }
          $rows[] = array(
            $last_position == $position ? '' : $position,
            empty($record['path']) ? '<em>'. t('none') . '</em>' : $record['path'],
            openadstream_output_terms($record['terms']),
            $date_from,
            $date_to,
            empty($record['bgcolor']) ? '<em>'. t('n/a') . '</em>' : $record['bgcolor'],
            l('edit', 'admin/build/openadstream/advanced-edit/'. $record['id']) .', '. l('delete', 'admin/build/openadstream/advanced-delete/'. $record['id']),
          );
          $last_position = $position;
        }
      }

      // Compile a themed table.
      $output .= theme('table', $header, $rows);
    }

/*
    // Add some separation between the two lists.
    $output .= "<br />\n";

    // Default positions.
    $positions = openadstream_all_positions_by_hook();
    $output .= "<h3>" .  t('Positions Added by Modules') . "</h3>\n";

    // If there were no positions, display a message.
    if (empty($positions)) {
      $output .= "<p>". t("No positions have been added by modules.") ."</p>";
    }

    else {
      // The table header.
      $header = array(
        t('Position Name'),
        t('Advanced?'),
        t('Description'),
        t('Module'),
      );
  
      // Add each row.
      $rows = array();
      foreach ($positions as $position) {
        $rows[] = array(
          $position['name'],
          $position['advanced'] ? t('Yes') : t('No'),
          $position['description'],
          $position['module'],
        );
      }
  
      // Compile a themed table.
      $output .= theme('table', $header, $rows);
    }
*/
  }

  return $output;
}

/**
 * Show the New Advanced Settings form.
 */
function openadstream_admin_advanced_add() {
  drupal_set_title(t("Add Advanced Position Setting"));
  return openadstream_admin_advanced_form();
}

/**
 * Show the New Advanced Settings form.
 */
function openadstream_admin_advanced_edit($form, $id) {
  drupal_set_title(t("Edit Advanced Position Setting"));

  $advanced = db_fetch_array(db_query("SELECT a.id, a.position, a.path, a.terms, a.date_from, a.date_to, a.bgcolor FROM {openadstream_advanced} a WHERE a.id=%d", $id));
  // Extract the terms, make sure it's an array.
  if (empty($advanced['terms'])) {
    $advanced['terms'] = array();
  }
  else {
    $advanced['terms'] = unserialize($advanced['terms']);
  }
  if (!is_array($advanced['terms'])) {
    $advanced['terms'] = array();
  }
  return openadstream_admin_advanced_form($advanced);
}

/**
 * Build the Advanced Settings path form.
 */
function openadstream_admin_advanced_form($record = array()) {
  $form = array();

  // See if any ad positions have the advanced options enabled.
  $positions = openadstream_all_positions_advanced(TRUE);

  // No positions found.
  if (empty($positions)) {
    $form['info'] = array(
      '#type' => 'fieldset',
      '#title' => t('Create New Advanced Settings Record'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );
    $form['info']['message'] = array(
      '#type' => 'markup',
      '#value' => t('No ad positions have been set to allow advanced settings.'),
    );
  }
  
  // Advanced settings allowed.
  else {
    // If this is an edit.
    if (is_array($record) && isset($record['id'])) {
      $form['id'] = array(
        '#type' => 'value',
        '#value' => $record['id'],
      );
      if (!empty($record['date_from'])) {
        $record['date_from'] = date_convert($record['date_from'], DATE_UNIX, DATE_DATETIME);
      }
      if (!empty($record['date_to'])) {
        $record['date_to'] = date_convert($record['date_to'], DATE_UNIX, DATE_DATETIME);
      }
    }
    // Assign some defaults.
    else {
      $record = array(
        'path' => NULL,
        'date_from' => NULL,
        'date_to' => NULL,
        'bgcolor' => NULL,
      );
    }

    $form['positions'] = array(
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#title' => t('Create New Advanced Settings Record'),
      '#description' => t('This provides more refined control over which pages the following ad position will display on, also allowing for date ranges and an option to override the page\'s background color.'),
    );
    $form['positions']['position'] = array(
      '#type' => 'select',
      '#title' => t('Ad Position to Use'),
      '#options' => openadstream_all_positions_advanced(),
      '#required' => TRUE,
    );

    $form['selection'] = array(
      '#type' => 'fieldset',
      '#title' => t('Selection Methods'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#description' => t('The ad wll only be enabled once it matches a path or term page defined here.'),
    );
    $form['selection']['paths'] = array(
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#title' => t('Path Settings'),
      '#description' => t('Paths that the ad will be activated on; this follows the standard Block Visiblity Rules style:
      <ul><li>One per line.</li><li>"*" may be used as a wildcard.</li><li>Can be used to match both the internal Drupal path (node/*, taxonomy/term/*) and the public-facing friendly URLs.</li></ul>
      Examples:
      <ul><li>"product*" will match the paths "product", "products" and "products/purple-people-eater".</li></ul>'),
    );
    $form['selection']['paths']['path'] = array(
      '#type' => 'textarea',
      '#title' => t('Paths to Include'),
      '#default_value' => $record['path'],
      '#required' => FALSE,
    );
    $form['selection']['terms_lists'] = array(
      '#type' => 'fieldset',
      '#title' => t('Terms'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#description' => t('Terms may be used instead of manually entering paths.  This will allow the ad to display on the corresponding <em>term page</em> for the selected terms.<br />Note: this does not enable the ad if content is simply tagged with that term.'),
    );
    // Compile nested fieldsets for each vocab.
    foreach (openadstream_vocabs() as $vid => $vocab) {
      $form['selection']['terms_lists']['vocab_'. $vid] = array(
        '#type' => 'fieldset',
        '#title' => t('Vocabulary') .': '. $vocab->name,
        '#collapsible' => TRUE,
        '#collapsed' => empty($record['terms'][$vocab->vid]),
      );
      $form['selection']['terms_lists']['vocab_'. $vid][$vid] = array(
        '#type' => 'checkboxes',
        '#title' => '',
        '#default_value' => $record['terms'][$vocab->vid],
        '#required' => FALSE,
        '#options' => $vocab->terms,
      );
    }
  
    $form['date_fields'] = array(
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#title' => t('Date Range (optional)'),
      '#description' => 'These may be combined to create specific effects, e.g. for ads that should start immediately and end on a specific date you should leave the "From" date blank and assign the "Until" date as needed.',
    );
    $form['date_fields']['date_from'] = array(
      '#type' => 'date_select',
      '#title' => t('From'),
      '#default_value' => $record['date_from'],
      '#required' => FALSE,
      '#date_year_range' => '-1:+3',
      '#description' => 'The date the ads will be visible on the above paths.  Optional.',
    );
    $form['date_fields']['date_to'] = array(
      '#type' => 'date_select',
      '#title' => t('Until'),
      '#default_value' => $record['date_to'],
      '#required' => FALSE,
      '#date_year_range' => '-1:+3',
      '#description' => 'The date the ads stop showing.  Optional.',
    );
    $form['background_color'] = array(
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#title' => t('Page Background Color (optional)'),
      '#description' => '',
    );
    $form['background_color']['bgcolor'] = array(
      '#type' => (module_exists('colorpicker') ? 'colorpicker_' : '') . 'textfield',
      '#title' => t('HEX Color Code'),
      '#default_value' => $record['bgcolor'],
      '#required' => FALSE,
      '#maxlength' => '7',
      '#size' => '10',
      '#description' => t('The default is "%bgcolor".  The color code for the page background.  This is only applicable for paths that are included.  Optional.', array('%bgcolor' => variable_get('openadstream_default_bgcolor', ''))),
    );
  
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => 'Save',
    );
  }

  return $form;
}

/**
 * Validate the data submitted in the advanced settings form.
 */
function openadstream_admin_advanced_add_validate($form, &$form_state) {
  $values = $form_state['values'];
  
  // Make sure the From date is not after the Until date.
  if (!empty($values['date_to']) && !empty($values['date_to'])) {
    $date_from = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    $date_to = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    
    if ($date_from > $date_to) {
      form_set_error('date_from', t('The "From" date should not be after the "Until" date'));
    }
  }
}

/**
 * Save the data submitted in the advanced settings form.
 */
function openadstream_admin_advanced_add_submit($form, &$form_state) {
  $values = $form_state['values'];

  // Compile the record.
  $obj = new stdClass;
  $obj->position = $values['position'];
  $obj->path = $values['path'];
  $obj->bgcolor = $values['bgcolor'];

  // Convert the date field to UNIX timestamp.
  if (!empty($values['date_from'])) {
    $values['date_from'] = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    $obj->date_from = $values['date_from'];
  }
  else {
    $obj->date_from = 0;
  }

  // Convert the date field to UNIX timestamp.
  if (!empty($values['date_to'])) {
    $values['date_to'] = date_convert($values['date_to'], DATE_DATETIME, DATE_UNIX);
    $obj->date_to = $values['date_to'];
  }
  else {
    $obj->date_to = 0;
  }
  
  // Load up the terms.
  $terms = array();
  // Grab the previously enabled vocabularies.
  $active_vocabs = array_values(array_filter(variable_get('openadstream_active_vocabs', array())));
  foreach ($active_vocabs as $vid) {
    $new_terms = array_values(array_filter($values[$vid]));
    if (!empty($new_terms)) {
      $terms[$vid] = $new_terms;
    }
  }
  $obj->terms = serialize(array_filter($terms));
  
  // Save the record.
  drupal_write_record('openadstream_advanced', $obj);

  // Clear the cache.
  openadstream_clear_advanced_cache();

  drupal_set_message(t('The advanced settings has been saved'));
  drupal_goto('admin/build/openadstream/advanced');
}

/**
 * Validate the data submitted in the advanced settings form.
 */
function openadstream_admin_advanced_edit_validate($form, &$form_state) {
  $values = $form_state['values'];
  
  // Make sure the From date is not after the Until date.
  if (!empty($values['date_to']) && !empty($values['date_to'])) {
    $date_from = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    $date_to = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    
    if ($date_from > $date_to) {
      form_set_error('date_from', t('The "From" date should not be after the "Until" date'));
    }
  }
}

/**
 * Save the data submitted in the advanced settings form.
 */
function openadstream_admin_advanced_edit_submit($form, &$form_state) {
  $values = $form_state['values'];

  // Compile the record.
  $obj = new stdClass;
  $obj->id = $values['id'];
  $obj->path = $values['path'];
  $obj->bgcolor = $values['bgcolor'];

  // Convert the date field to UNIX timestamp.
  if (!empty($values['date_from'])) {
    $values['date_from'] = date_convert($values['date_from'], DATE_DATETIME, DATE_UNIX);
    $obj->date_from = $values['date_from'];
  }
  else {
    $obj->date_from = 0;
  }

  // Convert the date field to UNIX timestamp.
  if (!empty($values['date_to'])) {
    $values['date_to'] = date_convert($values['date_to'], DATE_DATETIME, DATE_UNIX);
    $obj->date_to = $values['date_to'];
  }
  else {
    $obj->date_to = 0;
  }
  
  // Load up the terms.
  $terms = array();
  // Grab the previously enabled vocabularies.
  $active_vocabs = array_values(array_filter(variable_get('openadstream_active_vocabs', array())));
  foreach ($active_vocabs as $vid) {
    $new_terms = array_values(array_filter($values[$vid]));
    if (!empty($new_terms)) {
      $terms[$vid] = $new_terms;
    }
  }
  $obj->terms = serialize(array_filter($terms));
  
  // Save the record.
  drupal_write_record('openadstream_advanced', $obj, array('id'));

  // Clear the cache.
  openadstream_clear_advanced_cache();

  drupal_set_message(t('The advanced settings have been saved'));
  drupal_goto('admin/build/openadstream/advanced');
}

/**
 * Verify the user wants to delete a advanced settings record.
 */
function openadstream_admin_advanced_delete(&$form_state, $record_id) {
  $record = db_fetch_array(db_query("SELECT a.id, a.position, a.path, a.terms, a.date_from, a.date_to FROM {openadstream_advanced} a WHERE a.id = %d", $record_id));
  
  drupal_set_title(t("Advanced Position Setting"));
  
  $form = array(
    'id' => array(
      '#type' => 'value',
      '#value' => $record['id'],
    ),
  );
  
  return confirm_form($form,
    t("Are you sure you want to delete this advanced settings record?"),
    'admin/build/openadstream/advanced',
    t('This action cannot be undone'),
    t('Delete'), t('Cancel')
  );
}

/**
 * Process the delete-advanced-ad form.
 */
function openadstream_admin_advanced_delete_submit($formid, &$form_state) {
  if ($form_state['values']['confirm']) {
    db_query("DELETE FROM {openadstream_advanced} WHERE id = %d", $form_state['values']['id']);
    openadstream_clear_advanced_cache();
    drupal_set_message(t('The advanced settings record has been deleted.'));
  }
  $form_state['redirect'] = 'admin/build/openadstream/advanced';
}

// TODO: button to clear the cache.
